@@ -22,13 +22,8 @@ extern "C" {
 #include "rainbow/sha1.h"
 }
 
-#include <fcntl.h>
 #include <sys/stat.h>
 
-#include <netinet/in.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netdb.h>
 #include <unistd.h>
 #include <cstdio>
 #include <string>
@@ -452,8 +447,14 @@ ref_ptr<Resource> Rainbow::HubClient::create (const Glib::ustring &url)
 	if (!&*r) {
 		Mutex::Lock lock(db_mutex);
 		r = ref_ptr<Resource>(new Resource(url));
-		RdfResource::get_and_do(url, bind(slot(*this, &HubClient::parse_resource), &*r));
 		db.insert(make_pair(url, r));
+
+		if (r->has_rdf())
+			RdfResource::get_and_do(url, bind(slot(*this, &HubClient::parse_resource), &*r));
+		else {
+			r->available_locations.push_back(url);
+			r->obtained_info = true;
+		}
 	}
 	return r;
 }
@@ -531,7 +532,8 @@ void Rainbow::HubClient::prepare_resource (Resource *r)
 
 	r->downloading = true;
 
-	query_hub(r); // FIXME: make this asynchronous
+	if (r->has_rdf())
+		query_hub(r); // FIXME: make this asynchronous
 	start_download(r);
 }
 
@@ -728,7 +730,8 @@ void Rainbow::HubClient::uncache_resource (Resource *r)
 	unlink(r->filename.c_str());
 
 	// fixme: this should not be necessary now, but it needs to be done at some point in case you decide to download again
-	RdfResource::get_and_do(r->get_url(), bind(slot(*this, &HubClient::parse_resource), r));
+	if (r->has_rdf())
+		RdfResource::get_and_do(r->get_url(), bind(slot(*this, &HubClient::parse_resource), r));
 }
 
 // fixme: maybe size should be stored, with a boolean whether it's allocated or used
